package sun.management.jmxremote;

import java.util.Enumeration;
import java.net.InetAddress;
import java.net.SocketException;
import java.io.IOException;
import java.net.NetworkInterface;
import java.net.Socket;
import java.net.ServerSocket;
import java.rmi.server.RMIServerSocketFactory;

public final class LocalRMIServerSocketFactory implements RMIServerSocketFactory
{
    public LocalRMIServerSocketFactory() {
    }
    
    @Override
    public ServerSocket createServerSocket(final int n) throws IOException {
        return new ServerSocket(n) {
            @Override
            public Socket accept() throws IOException {
                Socket accept = super.accept();
                InetAddress inetAddress = accept.getInetAddress();
                if (inetAddress == null) {
                    String str = "";
                    if (accept.isClosed()) {
                        str = " Socket is closed.";
                    }
                    else if (!accept.isConnected()) {
                        str = " Socket is not connected";
                    }
                    try {
                        accept.close();
                    }
                    catch (Exception ex3) {}
                    throw new IOException("The server sockets created using the LocalRMIServerSocketFactory only accept connections from clients running on the host where the RMI remote objects have been exported. Couldn't determine client address." + str);
                }
                else {
                    if (inetAddress.isLoopbackAddress()) {
                        return accept;
                    }
                    Enumeration<NetworkInterface> networkInterfaces;
                    try {
                        networkInterfaces = NetworkInterface.getNetworkInterfaces();
                    }
                    catch (SocketException cause) {
                        try {
                            accept.close();
                        }
                        catch (IOException ex) {}
                        throw new IOException("The server sockets created using the LocalRMIServerSocketFactory only accept connections from clients running on the host where the RMI remote objects have been exported.", cause);
                    }
                    while (networkInterfaces.hasMoreElements()) {
                        Enumeration<InetAddress> inetAddresses = ((NetworkInterface)networkInterfaces.nextElement()).getInetAddresses();
                        while (inetAddresses.hasMoreElements()) {
                            if (((InetAddress)inetAddresses.nextElement()).equals(inetAddress)) {
                                return accept;
                            }
                            continue;
                        }
                    }
                    try {
                        accept.close();
                    }
                    catch (IOException ex2) {}
                    throw new IOException("The server sockets created using the LocalRMIServerSocketFactory only accept connections from clients running on the host where the RMI remote objects have been exported.");
                }
            }
        };
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof LocalRMIServerSocketFactory;
    }
    
    @Override
    public int hashCode() {
        return this.getClass().hashCode();
    }
}
